![PythonSupport](https://img.shields.io/static/v1?label=python&message=%203.8|%203.9|%203.10|%203.11&color=blue?style=flat-square&logo=python)
![PyPI version](https://badge.fury.io/py/xmodel-rest.svg?)

## Documentation

**[📄 Detailed Documentation](https://xyngular.github.io/py-xmodel-rest/latest/)** | **[🐍 PyPi](https://pypi.org/project/xmodel-rest/)**

## Getting Started

**warning "Alpha Software!"**

This is pre-release Alpha software, based on another code base and
the needed changes to make a final release version are not yet
completed. Everything is subject to change; and documentation needs
to be written.


```shell
poetry install xmodel-rest
```

or

```shell
pip install xmodel-rest
```
